==> mailman3_3.1.1.orig.tar.gz: mailman-3.1.1/src/mailman/commands/cli_aliases.py <==
# Copyright (C) 2009-2017 by the Free Software Foundation, Inc.
#
# This file is part of GNU Mailman.
#
# GNU Mailman is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option)
# any later version.
#
# GNU Mailman is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# GNU Mailman.  If not, see <http://www.gnu.org/licenses/>.

"""Generate Mailman alias files for your MTA."""

from mailman.config import config
from mailman.core.i18n import _
from mailman.interfaces.command import ICLISubCommand
from mailman.utilities.modules import call_name
from public import public
from zope.interface import implementer


@public
@implementer(ICLISubCommand)
class Aliases:
    """Regenerate the aliases appropriate for your MTA."""

    name = 'aliases'

    def add(self, parser, command_parser):
        """See `ICLISubCommand`."""
        self.parser = parser
        command_parser.add_argument(
            '-d', '--directory',
            action='store', help=_("""\
            An alternative directory to output the various MTA files to."""))

    def process(self, args):
        """See `ICLISubCommand`."""
        # Call the MTA-specific regeneration method.
        call_name(config.mta.incoming).regenerate(args.directory)

==> mailman3_3.2.0.orig.tar.gz: mailman-3.2.0/src/mailman/commands/cli_aliases.py <==
# Copyright (C) 2009-2018 by the Free Software Foundation, Inc.
#
# This file is part of GNU Mailman.
#
# GNU Mailman is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option)
# any later version.
#
# GNU Mailman is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# GNU Mailman.  If not, see <http://www.gnu.org/licenses/>.

"""Generate Mailman alias files for your MTA."""

import click

from mailman.config import config
from mailman.core.i18n import _
from mailman.interfaces.command import ICLISubCommand
from mailman.utilities.modules import call_name
from mailman.utilities.options import I18nCommand
from public import public
from zope.interface import implementer


@click.command(
    cls=I18nCommand,
    help=_('Regenerate the aliases appropriate for your MTA.'))
@click.option(
    '--directory', '-d',
    type=click.Path(exists=True, file_okay=False, resolve_path=True,
                    writable=True),
    help=_('An alternative directory to output the various MTA files to.'))
def aliases(directory):
    call_name(config.mta.incoming).regenerate(directory)


@public
@implementer(ICLISubCommand)
class Aliases:
    name = 'aliases'
    command = aliases
